@@ -128,19 +128,19 @@ class predictor(object):
                     self.layers.append(self.layerDict[cleanedLine](inputDims=1,
                                                                    outputDims=1))
 
-    def predict(self, inputMatrix, skip=1):
+    def predict(self, inputMatrix, n=1):
         """Make predictions from an ensemble of neural networks.
 
         Arguments:
             * inputMatrix: The input data
-            * skip: Predict using every n networks where n = skip
+            * n: Predict using every n networks
         Returns:
             * initialResults: List with all networks used
         """
 
         inputVal = np.transpose(inputMatrix)
-        initialResults = [None] * (self.numNetworks//skip)
-        for m in range(0, self.numNetworks, skip):
+        initialResults = [None] * (self.numNetworks//n)
+        for m in range(0, self.numNetworks, n):
             current = inputVal
             matrixIndex = 0
             for layer in self.layers:
@@ -150,34 +150,34 @@ class predictor(object):
                     tensorList.append(self.matrices[matrixIndex+x][m, :, :])
                 matrixIndex += numTensors
                 current = layer.predict(current, tensorList)
-            initialResults[m//skip] = current.numpy()
+            initialResults[m//n] = current.numpy()
 
         return(initialResults)
     
-    def trainProbs(self, trainX, trainY, skip, likelihood):
+    def trainProbs(self, trainX, trainY, n, likelihood):
         """ Calculate the negative log likelihoods for the training data.
         
         Arguments:
             * trainX: training input data
             * trainY: training output data
-            * skip: Predict using every n networks where n = skip
+            * n: Predict using every n networks
         
         """
         weights = []
         if(likelihood is not None):
             weights = self.likelihood.calcultateLogProb(input=tf.transpose(trainX),
                                                     realVals=trainY,
-                                                    skip=skip,
+                                                    n=n,
                                                     hypers = self.hypers,
                                                     predict = self.predict,
                                                     dtype=self.dtype)
         else:
-            for m in range(0, self.numNetworks, skip):
+            for m in range(0, self.numNetworks, n):
                 weights.append(tf.cast(0, self.dtype))
-        for m in range(0, self.numNetworks, skip):
+        for m in range(0, self.numNetworks, n):
             matrixIndex = 0
             hyperIndex = 0
-            current = -weights[m//skip]
+            current = -weights[m//n]
             for layer in self.layers:
                 numTensors = layer.numTensors
                 numHyperTensors = layer.numHyperTensors
@@ -190,10 +190,10 @@ class predictor(object):
                 hyperIndex += numHyperTensors
                 matrixIndex += numTensors
                 current -= tf.cast(layer.calculateHyperProbs(hyperList, tensorList), self.dtype).numpy()
-            weights[m//skip] = current
+            weights[m//n] = current
         self.weightsTrain = np.array(weights)
    
-    def reweight(self, architecture, trainX=None, trainY=None, skip=1, likelihood=None):
+    def reweight(self, architecture, trainX=None, trainY=None, n=1, likelihood=None):
         """ Calculate new weights for each network if they have the new 
         hyper paramters described in architecture. The weights are calculated
         according to p(theta|priors2)/p(theta|priors1). The new priors can be
@@ -204,14 +204,14 @@ class predictor(object):
             * trainX: training input data
             * trainY: training output data
             * architecture: new architecture file
-            * skip: Predict using every n networks where n = skip
+            * n: Predict using every n networks
         
         Returns:
             * weighting: Numpy array with new weights for the networks.
         """
         
         if(len(self.weightsTrain)==0):
-            self.trainProbs(trainX, trainY, skip, likelihood)
+            self.trainProbs(trainX, trainY, n, likelihood)
         
         self.loadArchitecture(architecture=architecture)
         
@@ -219,18 +219,18 @@ class predictor(object):
         if(likelihood is not None):
             weights = self.likelihood.calcultateLogProb(input=tf.transpose(trainX),
                                                     realVals=trainY,
-                                                    skip=skip,
+                                                    n=n,
                                                     hypers = self.hypers,
                                                     predict = self.predict,
                                                     dtype=self.dtype)
         else:
-            for m in range(0, self.numNetworks, skip):
+            for m in range(0, self.numNetworks, n):
                 weights.append(tf.cast(0, self.dtype))
 
-        for m in range(0, self.numNetworks, skip):
+        for m in range(0, self.numNetworks, n):
             matrixIndex = 0
             hyperIndex = 0
-            current = -weights[m//skip]
+            current = -weights[m//n]
             for layer in self.layers:
                 numTensors = layer.numTensors
                 numHyperTensors = layer.numHyperTensors
@@ -243,7 +243,7 @@ class predictor(object):
                 hyperIndex += numHyperTensors
                 matrixIndex += numTensors
                 current -= tf.cast(layer.calculateHyperProbs(hyperList, tensorList), self.dtype).numpy()
-            weights[m//skip] = current
+            weights[m//n] = current
         self.weights = np.array(weights)
         
         weighting = np.exp(self.weightsTrain-weights)
@@ -257,13 +257,13 @@ class predictor(object):
         """ Calcualte the Pearson product-moment correlation between networks.
         
         Arguments:
-            * skip: Predict using every n networks where n = skip
+            * n: Predict using every n networks
             
         Returns:
             * coef: The coefficients between the networks used
         
         """
-        predictions = self.predict(inputData, skip=1)
+        predictions = self.predict(inputData, n=1)
         output = np.squeeze(np.array(predictions)).T
         
         valFunc=0
@@ -280,7 +280,7 @@ class predictor(object):
         return(valFunc)
         
     def integratedAutoCorrelationTime(self, inputData):
-        predictions = self.predict(inputData, skip=1)
+        predictions = self.predict(inputData, n=1)
         output = np.squeeze(np.array(predictions)).T
         
         val=0
